/*
 * PluginExtension.java
 *
 * Created on July 29, 2005, 10:27 AM
 *
 * To change this template, choose Tools | Options and locate the template under
 * the Source Creation and Management node. Right-click the template and choose
 * Open. You can then make changes to the template in the Source Editor.
 */

package lu.tudor.santec.settings;

import java.beans.PersistenceDelegate;

import javax.swing.JPanel;

import javax.swing.border.TitledBorder;

import lu.tudor.santec.i18n.Relocalizable;

/**
 *
 * @author nmac
 */
//***************************************************************************
//* Class Definition and Members                                            *
//***************************************************************************

public class PluginExtension extends JPanel implements Relocalizable
    {
    private SettingsPlugin  m_Owner;
    
//***************************************************************************
//* Constructor                                                             *
//***************************************************************************

//---------------------------------------------------------------------------
/** Creates a new instance of PluginExtension */
//---------------------------------------------------------------------------

public PluginExtension(String p_Title) 
    {
    setBorder (new TitledBorder (p_Title));
    }

//***************************************************************************
//* Class Body                                                              *
//***************************************************************************

//===========================================================================
//= Primary Extension interface                                             =
//===========================================================================

//---------------------------------------------------------------------------
/**
 * extensionAdded method will be called automatically AFTER the extension has been
 * added to the plugin. Method could be used for instance to add stationary
 * values to those of the plugin.
 */
//---------------------------------------------------------------------------

protected void extensionAdded ()
    {
    }

//---------------------------------------------------------------------------
/**
 * the setOwner method will be called by the SettingsPlugin upon call to the
 * addExtension method. The Extension owner MUST be set before the extension can access 
 * the centrally stored settings. You don't need to call this method explicitly
 * as it will be called automatically by the owner.
 * @param p_Owner specifies the Plugin this Extension was added to.
 * @param p_ExtensionID uniquely identifies the extension among all the extensions owned by the Plugin
 */
//---------------------------------------------------------------------------

public void setOwner (SettingsPlugin p_Owner) 
    {
    if (p_Owner != null) 
        {
        m_Owner = p_Owner;
        extensionAdded ();
        }
    }

//---------------------------------------------------------------------------
/**
 * retrieves the default value of the setting specified by p_Key. Calling this method 
 * will only have an effect after defaults were loaded by calling loadDefaults method.
 * @param p_Key specifies the name of the setting to get the default value of.
 * @return default value of specified setting if exists, NULL otherwise
 */
//---------------------------------------------------------------------------

protected Object getDefault (String p_Key)
    {
    Object l_Default = null;
    
    if (m_Owner != null) l_Default = m_Owner.getDefault (p_Key);

    return l_Default;
    }

//---------------------------------------------------------------------------
/**
 * sets the setting specified by p_Key to the value specified by p_Value. Calling 
 * this method will only have an effect after the extension was added to the Plugin.
 * @param p_Key specifies the name of the setting to set in the centrally stored settings.
 * @param p_Value specifies the value to set the setting to
 */
//---------------------------------------------------------------------------

protected void setValue (String p_Key, Object p_Value) 
    {
    if (m_Owner != null) m_Owner.setValue (p_Key,p_Value);
    }

//---------------------------------------------------------------------------
/**
 * returns the value of the setting specified by p_Key. Calling this method will 
 * only have an effect after the extension was added to the Plugin.
 * @param p_Key specifies the name of the setting to get the value of.
 * @return the value of the specified setting if exists (and extension was already added
 * to plugin), <B>NULL</B> otherwise
 */
//---------------------------------------------------------------------------

public Object getValue (String p_Key)
    {
    Object l_Value = null;
    
    if (m_Owner != null) l_Value = m_Owner.getValue (p_Key);

    return l_Value;
    }

//---------------------------------------------------------------------------
/**
 * sets the stationary value for setting specified by p_Key to the value specified
 * by p_Value. Calling this method will only have an effect after the extension 
 * was added to the Plugin.
 * @param p_Key specifies the setting to set stationary value for.
 * @param p_Value specifies the stationary value.
 * @see method should only be called AFTER extension has been added to plugin! Method
 * tries to add specified stationary value to those of the plugin. See method
 * extensionAdded
 */
//---------------------------------------------------------------------------

protected void setStationary (String p_Key, Object p_Value)
    {
    if (m_Owner != null) m_Owner.setStationary (p_Key,p_Value);
    }

//---------------------------------------------------------------------------
/**
 * sets the enabled state of the subpanel specified by p_SubPanelID to the value
 * specified by p_Enabled. Calling this method will only have an effect after the 
 * extension was added to the Plugin.
 * @param p_SubPanelID specifies the target sub-panel. Top-most sub-panel has ID 0
 * @param p_Enabled specifies whether to enable or disable specified sub-panel
 */
//---------------------------------------------------------------------------

protected void setPluginPanelEnabled (int p_PanelID, boolean p_Enabled)
    {
    if (m_Owner != null) m_Owner.setSubPanelEnabled (p_PanelID, p_Enabled);
    }

//---------------------------------------------------------------------------
/**
 * adds the Persistence Delegate specified by p_Delegate for class specified by p_Class. 
 * Persistence Delegates take the responsibility for expressing the state of an instance 
 * of a given class. XMLEncoder  class is exclusively designed for the purpose of archiving 
 * graphs of JavaBeans as textual representations of their public properties. Persistence 
 * Delegates are required for storing non JavaBeans compliant classes.
 * @param p_Class specifies the class to add a Persistence Delegate for
 * @param p_Delegate specifies the persistence delegate object to be associated with specifed class
 */
//---------------------------------------------------------------------------

public void addPersistenceDelegate (Class p_Class, PersistenceDelegate p_Delegate)
    {
    if (m_Owner != null) m_Owner.addPersistenceDelegate (p_Class,p_Delegate);
    }

//---------------------------------------------------------------------------
/**
 * called by the owner upon Apply or Okay action to initiate update of centrally
 * stored settings. Extensions should respond by updating settings so that they reflect
 * the state of extension controls. Method MUST be overwritten by inheriting extensions.
 */
//---------------------------------------------------------------------------

public void updateSettings ()
    {
    }

//---------------------------------------------------------------------------
/**
 * called by the owner upon Cancel action to revert to centrally stored
 * settings. Extensions should respond by updating extensions controls to centrally
 * stored values.
 */
//---------------------------------------------------------------------------

public void reflectSettings ()
    {
    }

//---------------------------------------------------------------------------
/**
 * called by the owner upon Revert action to revert to default settings.
 * Extensions should respond by updating extensions controls to default values.
 */
//---------------------------------------------------------------------------

public void revertToDefaults ()
    {
    }

//---------------------------------------------------------------------------
/**
 * Method is part of the Relocalizable interface. The method does everything
 * required to reflect changes of active Locale
 */
//---------------------------------------------------------------------------

public void relocalize ()
    {
    }

//***************************************************************************
//* End Of Class                                                            *
//***************************************************************************
   
}
